@@ -19,6 +19,9 @@ class DictLikeGetter:
     def __getitem__(self, item):
         return getattr(self, item)
 
+    def __setitem__(self, key, value):
+        setattr(self, key, value)
+
 
 
 
